@@ -34,6 +34,9 @@ class FactTestCase(unittest.TestCase):
                 e. Fact columns should be aggregated wherever possible
         '''
 
+        if not self.__excludeFromAggregation:
+            self.skipTest("the set of columns excluded from aggregation testing cannot be None or empty...")
+
         event = TestEvent(Utilities.get_function_caller_name())
 
         eventCode1 = "fact-columns"
